unit uEditUI;
{$INCLUDE 'Plugin.inc'}

interface

uses
  Windows, SysUtils, Classes,
  {$INCLUDE 'DelphiFarUnits.inc'} ;

type
  TEditNamedFolderDialog = class(TOkCancelDialog)
  private
    fName: string;
    fDirectory: string;
    fParam: string;
    fHostFile: string;
    fPluginID: TGUID;
    fDescription: string;
  private
    fLabelName: TFarDialog.TLabel;
    fEditName: TFarDialog.TEdit;
    fLabelDescription: TFarDialog.TLabel;
    fEditDescription: TFarDialog.TEdit;
    fLabelDirectory: TFarDialog.TLabel;
    fEditDirectory: TFarDialog.TEdit;
    fLabelPluginID: TFarDialog.TLabel;
    fEditPluginID: TFarDialog.TEdit;
    fLabelParam: TFarDialog.TLabel;
    fEditParam: TFarDialog.TEdit;
    fLabelHostFile: TFarDialog.TLabel;
    fEditHostFile: TFarDialog.TEdit;
  protected
    procedure Clear; override;
    procedure CreateUserControls; override;
    procedure SetSize(Width, Height: Integer); override;
    procedure ConsoleSizeToDialogSize(var Width, Height: Integer); override;
    procedure EditNameChanged(Sender: TFarDialog.TCustomEdit; var AcceptChanges: Boolean);
    property LabelName: TFarDialog.TLabel read fLabelName;
    property EditName: TFarDialog.TEdit read fEditName;
    property LabelDescription: TFarDialog.TLabel read fLabelDescription;
    property EditDescription: TFarDialog.TEdit read fEditDescription;
    property LabelDirectory: TFarDialog.TLabel read fLabelDirectory;
    property EditDirectory: TFarDialog.TEdit read fEditDirectory;
    property LabelPluginID: TFarDialog.TLabel read fLabelPluginID;
    property EditPluginID: TFarDialog.TEdit read fEditPluginID;
    property LabelParam: TFarDialog.TLabel read fLabelParam;
    property EditParam: TFarDialog.TEdit read fEditParam;
    property LabelHostFile: TFarDialog.TLabel read fLabelHostFile;
    property EditHostFile: TFarDialog.TEdit read fEditHostFile;
  public
    constructor Create;
    destructor Destroy; override;
    function Execute: boolean;
    property Name: string read fName write fName;
    property Directory: string read fDirectory write fDirectory;
    property PluginID: TGUID read fPluginID write fPluginID;
    property Param: string read fParam write fParam;
    property HostFile: string read fHostFile write fHostFile;
    property Description: string read fDescription write fDescription;
  end;

implementation

uses
  uMessages, uPluginConsts;

const
  GuidMask  = '{HHHHHHHH-HHHH-HHHH-HHHH-HHHHHHHHHHHH}';
  GuidEmpty = '{        -    -    -    -            }';

{ TEditNamedFolderDialog }

procedure TEditNamedFolderDialog.Clear;
begin
  inherited;
  fEditName := nil;
  fEditDirectory := nil;
  fEditPluginID := nil;
  fEditParam := nil;
  fEditHostFile := nil;
  fEditDescription := nil;
end;

constructor TEditNamedFolderDialog.Create;
begin
  inherited Create(DIALOG_EDITNAMEDFOLDER_GUID);
  HelpTopic := HELP_EDITOR;
end;

procedure TEditNamedFolderDialog.CreateUserControls;
begin
  inherited;
  fLabelName := AddLabel(0, 0, 0, GetMsg(MEditName));
  fEditName := AddEdit(0, 0, 0, '');
  fEditName.History := HISTORY_NAME;
  fEditName.OnChange := EditNameChanged;
  fLabelDescription := AddLabel(0, 0, 0, GetMsg(MEditDescription));
  fEditDescription := AddEdit(0, 0, 0, '');
  fEditDescription.History := HISTORY_DESCRIPTION;
  fLabelDirectory := AddLabel(0, 0, 0, GetMsg(MEditDirectory));
  fEditDirectory := AddEdit(0, 0, 0, '');
  fEditDirectory.History := HISTORY_DIRECTORY;
  fLabelPluginID := AddLabel(0, 0, 0, GetMsg(MEditPluginID));
  fEditPluginID := AddEdit(0, 0, 0, '');
  fEditPluginID.History := HISTORY_PLUGINID;
  fEditPluginID.Mask := GuidMask;
  fLabelParam := AddLabel(0, 0, 0, GetMsg(MEditParam));
  fEditParam := AddEdit(0, 0, 0, '');
  fEditParam.History := HISTORY_PARAM;
  fLabelHostFile := AddLabel(0, 0, 0, GetMsg(MEditHostFile));
  fEditHostFile := AddEdit(0, 0, 0, '');
  fEditHostFile.History := HISTORY_HOSTFILE;
end;

destructor TEditNamedFolderDialog.Destroy;
begin
  inherited;
end;

procedure TEditNamedFolderDialog.EditNameChanged(Sender: TFarDialog.TCustomEdit; var AcceptChanges: Boolean);
var
  OK: boolean;
  s: string;
  i: integer;
begin
  OK := True;
  s := EditName.Text;
  for i := 1 to Length(s) do
  begin
    if (s[i] = '\') or (s[i] = '/') then
    begin
      OK := False;
      Break;
    end;
  end;
  ButtonOK.Enabled := OK;
end;

function TEditNamedFolderDialog.Execute: boolean;
var
  PluginIDStr: string;
begin
  Result := False;
  EditName.Text := Name;
  EditDescription.Text := Description;
  EditDirectory.Text := Directory;
  EditPluginID.Text := GUIDToString(PluginID);
  EditParam.Text := Param;
  EditHostFile.Text := HostFile;
  if inherited Execute then
  begin
    Name := EditName.Text;
    Description := EditDescription.Text;
    Directory := EditDirectory.Text;
    PluginIDStr := EditPluginID.Text;
    if (PluginIDStr = '') or (PluginIDStr = GuidEmpty) then
      PluginID := GUID_NULL
    else
      PluginID := StringToGUID(PluginIDStr);
    Param := EditParam.Text;
    HostFile := EditHostFile.Text;
    Result := True;
  end;
end;

procedure TEditNamedFolderDialog.SetSize(Width, Height: Integer);
begin
  inherited;
  AutoPos(LabelName);
  AutoPos(EditName);
  AutoPos(LabelDescription);
  AutoPos(EditDescription);
  AutoPos(LabelDirectory);
  AutoPos(EditDirectory);
  AutoPos(LabelPluginID);
  AutoPos(EditPluginID);
  AutoPos(LabelParam);
  AutoPos(EditParam);
  AutoPos(LabelHostFile);
  AutoPos(EditHostFile);
  EditName.Width := 10;
  EditPluginID.Width := 40;
end;

procedure TEditNamedFolderDialog.ConsoleSizeToDialogSize(var Width, Height: Integer);
begin
  inherited;
  Height := 18;
end;

end.
